@@ -17,7 +17,7 @@
 
 import sys, os, jinja2, yaml, argparse, re, copy, getpass, datetime, pytz, traceback
 
-__version__ = '1.8.5'
+__version__ = '1.9.0'
 jinja2_filters = []
 
 def import_filters(errc = 0):
@@ -217,7 +217,8 @@ def main():
     if import_filters() > 0:
       print()
 
-    args.ed = [os.getcwd(), os.getenv('HOME') + '/.jinjafx'] + args.ed
+    base = os.path.abspath(os.path.dirname(__file__))
+    args.ed = [base + '/extensions', os.getcwd(), os.getenv('HOME') + '/.jinjafx'] + args.ed
     outputs = JinjaFx().jinjafx(args.t, data, gvars, args.o, args.ed)
     ocount = 0
 
@@ -457,9 +458,6 @@ class JinjaFx():
           r = True if field.startswith('-') else False
           self.__g_datarows[1:] = sorted(self.__g_datarows[1:], key=lambda n: n[self.__g_datarows[0].index(field.lstrip('+-')) + 1], reverse=r)
 
-    if 'jinja2_extensions' not in gvars:
-      gvars.update({ 'jinja2_extensions': [] })
-
     jinja2_options = {
       'undefined': jinja2.StrictUndefined,
       'trim_blocks': True,
@@ -467,6 +465,10 @@ class JinjaFx():
       'keep_trailing_newline': True
     }
 
+    if 'jinja2_extensions' not in gvars:
+      gvars.update({ 'jinja2_extensions': [] })
+
+    gvars['jinja2_extensions'].insert(0, 'ext.jinjafx')
     sys.path += exts_dirs
 
     if isinstance(template, bytes) or isinstance(template, str):
